* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard)
  * Using and Analyzing Executive KPIs
